from django.utils.text import capfirst
from django.core.urlresolvers import reverse
from django.contrib.contenttypes.models import ContentType
from django.utils.translation import ugettext_lazy as _

from jumbo.utils.charts import Chart, Property, SubProperty

from admin_tools.dashboard import modules
from ticket.models import Ticket, TicketProject

class TicketDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': "Tickets",
            'display': "tabs",
            'children': [
                TicketModels(),
                TicketOtherModels(),
                TicketSettings(),
            ]
        }
        super(TicketDashboard, self).__init__(**kwargs)

class TicketModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Models"),
            'models': (
                'ticket.models.Ticket', 'ticket.models.Category', 'ticket.models.Tipology'
                'ticket.models.TicketAssistance', 'ticket.models.TicketProject'),
            }
        super(TicketModels, self).__init__(**kwargs)

class TicketOtherModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Others"),
            'models': (
                'ticket.models.TicketUser',
            ),
        }
        super(TicketOtherModels, self).__init__(**kwargs)

class TicketSettings(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Settings"),
            'models':['ticket.models.Settings',],
            }
        super(TicketSettings, self).__init__(**kwargs)
class Tickets(modules.Group):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': "Tickets",
            'children': [
                TicketGraph(title='Open'),
                TicketList(title='Oldest Open', status=[0], order_by='date_create'),
            ],
        }   
        super(Tickets, self).__init__(**kwargs)

class TicketProjects(modules.Group):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': "Ticket Projects",
            'children': [
                TicketProjectList(
                    title='To Assign', status=[1],
                    managers='is_null', staff='is_null',
                    order_by='date_start'
                ),
            ],
        }   
        super(TicketProjects, self).__init__(**kwargs)

class TicketGraph(modules.DashboardModule):
    def __init__(self, title, **kwargs):
        self.template = 'admin_tools/dashboard/ticketgraph.html'
        self.series_type = 'line'
        self.title = title
        self.title_graph = ''
        self.subtitle_graph = ""
        self.label = None
        self.textX = 'text x'
        self.textY = 'text y'
        self.width = 450
        self.height = 280
        self.queryset = Ticket.objects.all()
        
        # creo o sovrascrivo con attributi passati
        for key in kwargs:
            setattr(self, key, kwargs[key])

        kwargs =  {
            'title': title,
            'template': self.template,
            'children': self.children
        }
   
    def init_with_context(self, context):
        request = context['request']
        self.dataX = [1,2,3,4,5,6,7]   
        self.dataY = [1,2,2,1,6,5,3]
        
        # options of char 
        chart = Chart(
            'graph1', defaultSeriesType=self.series_type,
            width=self.width, height=self.height
        )
        chart.add_property('title', text=self.title_graph)
        chart.add_property('subtitle', text=self.subtitle_graph)
        chart.add_property(
            'xAxis', categories=self.dataX, title={'text': self.textX}
        )
        chart.add_property('yAxis', title={'text': self.textY})
        chart.add_property('tooltip', crosshairs=True, shared=True)
        if self.label:
            chart.add_property('legend', enabled=True)
        else:
            chart.add_property('legend', enabled=False)
        chart.add_series(data=self.dataY)
        context['chart'] = chart

class TicketList(modules.DashboardModule):
    def __init__(self, title, **kwargs):
        self.template = 'admin_tools/dashboard/tickets.html'
        self.queryset = Ticket.objects.all()
        self.status = None
        self.limit = 10
        self.order_by = None
        self.children = ''

        # creo o sovrascrivo con attributi passati
        for key in kwargs:
            setattr(self, key, kwargs[key])
   
        kwargs =  {
            'title': title,
            'template': self.template,
            'children': self.children
        }
        super(TicketList, self).__init__(**kwargs)

    def init_with_context(self, context):
        request = context['request']
        qs = self.queryset
        if self.order_by: qs = qs.order_by(self.order_by)
        if self.status: qs = qs.filter(status__in=self.status)
        if self.limit: qs = qs[:self.limit]
        self.children = qs

class TicketProjectList(modules.DashboardModule):
    def __init__(self, title, **kwargs):
        self.template = 'admin_tools/dashboard/projects.html'
        self.queryset = TicketProject.objects.all()
        self.status = None
        self.limit = None
        self.managers = None
        self.staff = None
        self.order_by = None
        self.children = ''

        # creo o sovrascrivo con attributi passati
        for key in kwargs:
            setattr(self, key, kwargs[key])
   
        kwargs =  {
            'title': title,
            'template': self.template,
            'children': self.children
        }
        super(TicketProjectList, self).__init__(**kwargs)

    def init_with_context(self, context):
        request = context['request']
        qs = self.queryset
        if self.order_by: qs = qs.order_by(self.order_by)
        if self.status: qs = qs.filter(status__in=self.status)
        if self.managers and self.managers == 'is_null':
            qs = qs.filter(managers__isnull=True)
        if self.staff and self.staff == 'is_null':
            qs = qs.filter(staff__isnull=True)
        if self.limit: qs = qs[:self.limit]
        self.children = qs
