from django.core.mail import EmailMultiAlternatives
from jumbo.core.urlresolvers import reverse
from jumbo.utils.functions import get_settings
from jumbo.shortcuts import render_to_string

class TicketEmail(object):
    def __init__(self, request, obj, form, change):
        self.request = request
        self.obj = obj
        self.form = form
        self.change = change
        self.set_status_ticket()

        self.subject_msg = self.get_subject_msg()
        self.body_msg = self.html_body_msg = self.get_body_msg()
        self.from_mail = self.obj.get_from_mail()
        self.recipient_list = self.get_recipient_list()


    def set_status_ticket(self):
        self.is_closed = False
        self.is_reopen = False
        self.is_modify = False

        status = self.form.cleaned_data.get('status', 1)
        if status == 0:
            self.is_closed = True

        if status != 0 and self.obj.status == 0:
            self.is_reopen = True

        if self.change:
            self.is_modify = True


    #def get_subject_msg(self):
    #    self.subject_msg = "[Thunder Ticket]"
    #    if self.is_closed:
    #        self.subject_msg += "[CHIUSO] Ticket %s" % self.obj.id
    #    elif self.is_reopen:
    #        self.subject_msg += "[RIAPERTO] Ticket %s" % self.obj.id
    #    elif self.is_modify:
    #        self.subject_msg += "[MODIFICATO] Ticket %s" % self.obj.id
    #    else:
    #        self.subject_msg += "[APERTO] Ticket %s" % self.obj.id
    #    if self.obj.project:
    #        self.subject_msg += " - Progetto : %s" % self.obj.project
    #    else:
    #        self.subject_msg += " - Progetto Generico"
    #    return self.subject_msg

    def get_subject_msg(self):
        project = self.form.cleaned_data.get('project', None)
        self.subject_msg = get_settings("ticket.settings", "TICKET_SUBJECT_PREFIX")
        show_subject_info_project = get_settings("ticket.settings", "TICKET_SHOW_SUBJECT_INFO_PROJECT")
        if project and show_subject_info_project:
            self.subject_msg = "%s[#%s]" % (get_settings("ticket.settings", "TICKET_SUBJECT_PREFIX"), project.id)
        if self.is_closed:
            self.subject_msg += "[CHIUSO] - #%s - %s" % (self.obj.id, self.obj.title)
        elif self.is_reopen:
            self.subject_msg += "[RIAPERTO] - #%s - %s" % (self.obj.id, self.obj.title)
        elif self.is_modify:
            self.subject_msg += "[MODIFICATO] - #%s - %s" % (self.obj.id, self.obj.title)
        else:
            self.subject_msg += "[APERTO] - #%s - %s" % (self.obj.id, self.obj.title)
        return self.subject_msg


    def get_body_msg(self):
        self.body_msg = render_to_string("ticket/email/ticket_info_base.html",
                                         ticket = self.obj,
                                         status_ticket = self.get_status_ticket())
        return self.body_msg


    def get_recipient_list(self):
        project = self.form.cleaned_data.get('project', None)
        assigned_to = self.form.cleaned_data.get('assigned_to', [])

        return self._get_assegnatari(project, assigned_to)


    def _get_assegnatari(self, project, assigned_to):
        # recupero gli assegnatari del ticket
        assegnatari = set([ u.user.email for u in assigned_to if u.user.email ])
        #assegnatari = set(self.form.cleaned_data.get('assigned_to', []))

        # se l'assegnatario (il submitter) non e' presente negli assegnatari lo aggiungo
        #if self.obj.submitter and self.obj.submitter.email:
        #    assegnatari.add(self.obj.submitter.email)

        # se chi ha assegnato il ticket (l'assigned_by) non e' presente negli assegnatari lo aggiungo
        if self.obj.assigned_by and self.obj.assigned_by.user.email:
            assegnatari.add(self.obj.assigned_by.user.email)

        # Se al ticket e' associato un progetto aggiungo i responsabili di quest'ultimo
        if project:
            manager = project.get_list_managers()
            for m in manager:
                if m.user.email:
                    assegnatari.add(m.user.email)

        return assegnatari


    def get_status_ticket(self):
        status = self.form.cleaned_data.get('status', 1)
        if status == 0:
            return "chiuso"

        if status != 0 and self.obj.status == 0:
            return "riaperto"

        if self.change:
            return "modificato"

        else:
            return "inserito"


    def send(self):
        submitter = None
        if self.obj.submitter and self.obj.submitter.email:
            submitter = [self.obj.submitter.email]

        if self.recipient_list:
            msg = EmailMultiAlternatives(self.subject_msg,
                                         self.body_msg,
                                         self.from_mail,
                                         to=submitter,
                                         bcc=self.recipient_list)

            msg.attach_alternative(self.html_body_msg, "text/html")
            msg.send()


class TicketCloseMail(TicketEmail):
    def __init__(self, ticket):
        self.is_closed = False
        self.obj = ticket
        self.subject_msg = "[Thunder Ticket][CHIUSO] - #%s - %s" % (ticket.id, ticket.title)
        if self.obj.project:
            self.subject_msg = "[Thunder Ticket][#%s][CHIUSO] - #%s - %s" % (ticket.project.id, ticket.id, ticket.title)
        self.body_msg = self.html_body_msg = self.get_body_msg()
        self.from_mail = ticket.get_from_mail()
        self.recipient_list = self.get_recipient_list()

    def get_body_msg(self):
        self.body_msg = render_to_string("ticket/email/ticket_info_base.html",
                                         ticket = self.obj,
                                         status_ticket = 'chiuso')
        return self.body_msg

    def get_recipient_list(self):
        project = self.obj.project
        assigned_to = self.obj.assigned_to.all()

        return self._get_assegnatari(project, assigned_to)


class TicketEmailNonAssegnato(TicketEmail):
    def __init__(self, request, obj, form, change):
        super(TicketEmailNonAssegnato, self).__init__(request, obj, form, change)

    def get_recipient_list(self):
        return get_settings('ticket.settings', 'TICKET_MAIL_ADMIN')

    def get_subject_msg(self):
        self.subject_msg = "[Thunder Ticket][NON ASSEGNATO] - #%s - %s" % (self.t.id, self.t.title)
        return self.subject_msg

    def get_body_msg(self):
        self.body_msg = render_to_string("ticket/email/ticket_info_noassegnatari.html",
                                         ticket = self.t,
                                         status_ticket = self.get_status_ticket())
        return self.body_msg
