import datetime

from django.utils.translation import ugettext as _
from django.core.urlresolvers import reverse
from admin_tools.menu import items, Menu
from jumbo.conf.admin_menu import GenericMenuItem
from jumbo.middleware.thread_local import get_current_user

def get_root_menu(children):
    user = get_current_user()
    if not user.has_perm("ticket.view_ticket"):
        return None

    root_menu = items.MenuItem(
        title=_('Ticket'),
        children=[],
        url = "%s?status__in=1,2,3,6,7" % reverse('admin:ticket_ticket_changelist')
    )
    children.append(root_menu)

def add_extended_menuitems(children, current_app):
    gm = GenericMenuItem(current_app, [])
    user = get_current_user()

    add_ticket = items.MenuItem(
        title=_('Add ticket'),
        children=[],
        url = '%s' % reverse('admin:ticket_ticket_add')
    )
    list_open_ticket = items.MenuItem(
        title=_('List Open tickets'),
        children=[],
        url = '%s?status__in=1,2,3,6,7' % reverse('admin:ticket_ticket_changelist')
    )
    list_expired_ticket = items.MenuItem(
        title=_('List expired tickets'),
        children=[],
        url = '%s?status__in=1,2,3,6,7&deadline=%s' % (reverse('admin:ticket_ticket_changelist'), datetime.date.today())
    )
    list_all_ticket = items.MenuItem(
        title=_('List All tickets'),
        children=[],
        url = '%s' % reverse('admin:ticket_ticket_changelist')
    )

    list_ticket_assistance = items.MenuItem(
        title=_('List assistances'),
        children=[],
        url = '%s?procedure=0' % reverse('admin:ticket_ticketassistance_changelist')
    )

    list_assistance_calendar = items.MenuItem(
        title=_('Assistances calendar'),
        children=[],
        url = '%scalendar/month/' % reverse('admin:ticket_ticketassistance_changelist')
    )

    ticket = items.MenuItem(
        title=_('Ticket'),
        children=[],
        url = "%s?status__in=1,2,3,6,7" % reverse('admin:ticket_ticket_changelist')
    )

    if user.has_perm('ticket.view_ticket'):
        ticket.children.append(list_all_ticket)
        ticket.children.append(list_open_ticket)
        ticket.children.append(list_expired_ticket)
    if user.has_perm('ticket.add_ticket'):
        ticket.children.append(add_ticket)
    if user.has_perm('ticket.view_ticket'):
        gm.add_father(ticket)

    ticket_assistance = items.MenuItem(
        title=_('Ticket assistances'),
        children=[],
        url = reverse('admin:ticket_ticketassistance_changelist')
    )

    if user.has_perm('ticket.view_ticketassistance'):
        ticket_assistance.children.append(list_ticket_assistance)
        ticket_assistance.children.append(list_assistance_calendar)
        gm.add_father(ticket_assistance)

    menu = gm.get_menu()
    [ children.append(tick_menu) for tick_menu in menu ]